#!/bin/bash

set -e

function keepgoing
{
  echo "Going to run:"
  echo "$@"
  if [ "$AUTO" ]
  then
    $@
  else
    echo "Hit enter to continue, enter any text to stop"
    read ENTRY
    if [ -n "$ENTRY" ]
    then
      exit 1
    else
      $@
    fi
  fi
}

if (echo "$@" | grep -iq "a")
then
  export AUTO="auto"
else
  export AUTO=""
fi

VMDIR=$(echo -e "import utah.config\nprint(utah.config.vmpath)" | python)
if ! [ -d "$VMDIR" ]
then
  CMD="mkdir -p \"$VMDIR\""
  echo "Creating directory to hold VM files"
  keepgoing $CMD
fi

SSHKEY=$(echo -e "import utah.config\nprint(utah.config.sshprivatekey)" | python)
if ! [ -d "$(dirname "$SSHKEY")" ]
then
  CMD="mkdir -p \"$(dirname "$SSHKEY")\""
  echo "Creating directory to hold SSH key"
  keepgoing $CMD
fi
if ! [ -f "$SSHKEY" ]
then
  CMD="ssh-keygen -t rsa -f $SSHKEY"
  echo "Creating SSH key"
  keepgoing $CMD
fi

export LOGOUT=""

if ! (groups | grep "kvm" | grep "libvirtd" | grep -q "utah")
then
  CMD="sudo usermod -a -G kvm,libvirtd,utah $(echo -e "import utah.config\nprint(utah.config.user)" | python)"
  echo "Adding user to required groups"
  echo "This is the only command that requires sudo access"
  keepgoing $CMD
  export LOGOUT="logout"
fi

set +e

CMD=/usr/share/utah/examples/vmtools-user-setup.sh
if [ -f "$CMD" ]
then
  echo "Setting up vm-tools config"
  keepgoing $CMD $AUTO
fi

if [ "$LOGOUT" ]
then
  echo "User groups were updated"
  echo "Please log out and back in to obtain updated group permissions"
fi
