"""
UTAH client exceptions
"""


class UTAHClientError(Exception):
    """
    Base class of all exceptions in the client
    """


class BadDir(UTAHClientError):
    """
    Raised when some test directory isn't found
    or and error happens when trying to change to it
    """


class MissingFile(UTAHClientError):
    """
    Raised when yaml file with metadata about tests
    cannot be found
    """


class BadMasterRunlist(UTAHClientError):
    """
    Raised when master runlist isn't in the expected format
    """


class YAMLParsingError(UTAHClientError):
    """
    Used to provided the filename and the location
    in which the parsing error happened when calling yaml.load
    """


class ValidationError(UTAHClientError):
    """
    Used to provide additional information when schema validation fails
    """


class MissingData(UTAHClientError):
    """
    Raised when there is missing data that is required for an object
    to proceed.
    """
