import os
import yaml

from common import DEFAULT_STATE_FILE, parse_yaml_file


class StateAgent(object):
    """
    State saving base class.

    Accepts a dictionary of state info and prints it to STDOUT.
    """

    state_file = DEFAULT_STATE_FILE

    def __init__(self, state_file=None):
        if state_file is not None:
            self.state_file = state_file

    def clean(self):
        """
        Clean up the state file if it exists.
        """
        # Don't fail if the state_file doesn't exists.
        try:
            os.remove(self.state_file)
        except OSError as e:
            if e.errno == 2:  # file not found
                pass

    def save_state(self, state):
        """
        Save state to the state_file.
        """

        fp = open(self.state_file, 'w')
        fp.write(str(state))
        fp.close()

    def load_state(self):
        """
        Load state from the state_file.
        """
        state = {}

        if os.path.exists(self.state_file):
            fp = open(self.state_file, 'r')
            state = fp.read()
            fp.close()

        return state


class StateAgentYAML(StateAgent):
    """
    YAML based state saver.
    """

    def save_state(self, state):
        """
        Output the state as YAML.
        """
        yaml_state = yaml.dump(state, default_flow_style=False)
        super(StateAgentYAML, self).save_state(yaml_state)

    def load_state(self):
        """
        Load state from YAML state_file.
        """

        state = {}

        if os.path.exists(self.state_file):
            state = parse_yaml_file(self.state_file)

        return state
