import os
import shutil

from utah.client.common import UTAH_DIR, MASTER_RUNLIST


def get_module_path():
    """
    Return the path for the 'utah' directory.

    This is used in tests to refer to the location where the branch resides.
    It is used in conjunction with running the self tests via:

    sudo nosetests utah/client/tests

    from the top-level directory in the repo.
    """
    import utah

    module_path = os.path.dirname(utah.__file__)

    del utah

    return module_path

master_runlist_content = """# utah/self_test.py master runlist
# needed for utah/self_test.py runs
---
publish:
  url: http://dashboard.local/api/add_result/
  token: testtoken
  name: precise-server-amd64
testsuites:
  - name: examples
    fetch_cmd: rsync -a {REPO_PATH}/client/examples/examples .
  - name: utah_tests
    fetch_cmd: rsync -a {REPO_PATH}/client/examples/utah_tests .
  - name: utah_tests_sample
    fetch_cmd: rsync -a {REPO_PATH}/client/examples/utah_tests_sample .
""".format(REPO_PATH=get_module_path())

master_runlist = os.path.join(UTAH_DIR, MASTER_RUNLIST)
master_runlist_bak = master_runlist + ".bak"
examples_dir = os.path.join(UTAH_DIR, 'testsuites', 'examples')
#examples_source = os.path.join(UTAH_CLIENT, 'examples')
examples_source = os.path.join(get_module_path(), 'client', 'examples')


def setUp():
    """
    Set up a master.run file that will copy our 'examples' directory to the
    testing directory (usually /var/lib/utah).
    """

    # If we're not root don't bother
    if os.geteuid() != 0 and os.getuid() != 0:
        return

    # save a copy of the master runlist
    if os.path.exists(master_runlist):
        os.rename(master_runlist, master_runlist_bak)

    # Copy the examples directory into the working directory
    if not os.path.exists(examples_dir):
        shutil.copytree(examples_source, examples_dir)

    fp = open(master_runlist, 'w')
    fp.write(master_runlist_content)
    fp.close()


def tearDown():
    """
    Cleanup after ourselves.
    """

    # If we're not root don't bother
    if os.geteuid() != 0 and os.getuid() != 0:
        return

    # restore the copy of the master runlist
    if os.path.exists(master_runlist_bak):
        os.rename(master_runlist_bak, master_runlist)
    else:
        os.remove(master_runlist)

    if os.path.exists(examples_dir):
        shutil.rmtree(examples_dir)
