import os
import unittest

# REQUIRES that the top level utah package be in the Python path.
from utah.client.common import (
        get_media_info,
        get_host_info,
        run_cmd,
        debug_print,
        CONFIG,
        )


class TestCommon(unittest.TestCase):
    """
    Tests for utah.client.common.
    """
    def test_get_media_info(self):
        """
        Test that if there is a media-info file that it is parsed.
        """
        media_info = get_media_info()

        print("media_info: {}".format(media_info))

        if os.path.exists('/var/log/installer/media-info'):
            self.assertFalse(media_info == '' or media_info is None)
        else:
            self.assertTrue(media_info is None)

    def test_get_host_info(self):
        """
        Test that get_host_info returns results.
        """

        host_info = get_host_info()

        print("host_info: {}".format(host_info))

        self.assertTrue(host_info is not None)

    def test_run_cmd(self):
        result = run_cmd('find . -name "*.py"')

        self.assertEqual(result['returncode'], 0)

    def test_debug_print(self):
        """
        Test that debug_print doesn't print when DEBUG is False unless
        'debug' is passed in and is True.
        """
        old_debug = CONFIG['DEBUG']

        CONFIG['DEBUG'] = True
        if not debug_print("testing debug_print"):
            raise Exception("didn't print with CONFIG['DEBUG'] set to True")

        CONFIG['DEBUG'] = False

        debug = debug_print("shouldn't be printed "
                            "unless common.CONFIG['DEBUG'] is True")
        self.assertEqual(debug,
                         CONFIG['DEBUG'],
                         "printed with CONFIG['DEBUG'] set to False")
        debug = debug_print("should be printed (using 'force=True')",
                            force=True)
        self.assertEqual(debug, True)

        CONFIG['DEBUG'] = old_debug

    def test_run_as(self):
        """
        Test that run_as functions correctly.
        """
        user = "nobody"
        result = run_cmd("touch /tmp/run_as_test.tmp", run_as=user)
        print("result: {}".format(result))

        self.assertEqual(result['returncode'], 0)
        self.assertEqual(result['user'], user)

        result = run_cmd("rm /tmp/run_as_test.tmp", run_as=user)
        print("result: {}".format(result))

        self.assertEqual(result['returncode'], 0)
        self.assertEqual(result['user'], user)

    def test_run_as_default(self):
        """
        Test that the default user is correctly identified.
        """

        result = run_cmd("touch /tmp/run_as_test.tmp")
        print("result: {}".format(result))

        self.assertEqual(result['returncode'], 0)
        self.assertNotEqual(result['user'], "unknown")

        result = run_cmd("rm /tmp/run_as_test.tmp")
        print("result: {}".format(result))

        self.assertEqual(result['returncode'], 0)
        self.assertNotEqual(result['user'], "unknown")
