import unittest
import yaml

from utah.client.result import (
        Result,
        ResultYAML,
        )


class TestResult(unittest.TestCase):
    def setUp(self):
        self.result_yaml = ResultYAML("result_yaml")
        self.result_text = Result("result")

        self.result = {
            'command': 'echo hi',
            'returncode': 0,
            'stdout': 'hi',
            'stderr': ''
        }

        self.result_fail = {
            'command': 'echo failure',
            'returncode': 2,
            'stdout': 'hi',
            'stderr': ''
        }

    def test_add_result(self):
        self.result_yaml.add_result(self.result)

        self.assertEqual(self.result_yaml.count_results(), 1)

        self.result_yaml.result()

    def test_result(self):
        self.result_yaml.add_result(self.result)

        # check that the result was added.
        self.assertEqual(self.result_yaml.count_results(), 1)

        self.result_yaml.result()

        # check that the result was processed and removed.
        self.assertEqual(self.result_yaml.count_results(), 0)

    def test_result_pass(self):
        """
        Test that adding a pass result sets the Result object's status
        to 'PASS'.
        """
        self.result_yaml.add_result(self.result)

        self.assertEqual(self.result_yaml.status, 'PASS')

    def test_result_failure(self):
        """
        Test that adding a failure result sets the Result object's status
        to 'ERROR'.
        """
        self.result_yaml.add_result(self.result_fail)

        self.assertEqual(self.result_yaml.status, 'ERROR')

    def test_result_clear_result(self):
        """
        Test that the result is actually cleared.
        """
        self.result_yaml.add_result(self.result_fail)
        self.assertEqual(self.result_yaml.status, 'ERROR')

        self.result_yaml.clear_results()

        self.assertEqual(self.result_yaml.status, 'PASS')
        self.assertEqual(self.result_yaml.count_results(), 0)

    def test_result_result(self):
        """
        Test that ERROR status is retained after adding pass
        results.
        """
        self.result_yaml.add_result(self.result_fail)

        self.assertEqual(self.result_yaml.status, 'ERROR')

        self.result_yaml.add_result(self.result)

        self.assertEqual(self.result_yaml.status, 'ERROR')

    def test_result_yaml(self):
        self.result_yaml.add_result(self.result)

        import sys
        import StringIO

        str_output = StringIO.StringIO()

        # redirect output to a string
        old_stdout = sys.stdout
        sys.stdout = str_output

        self.result_yaml.result()

        sys.stdout = old_stdout

        result_str = str_output.getvalue()

        print("result_str: %s" % result_str)

        data = yaml.load(result_str)

        self.assertEqual(len(data['commands']), 1)

        result = data['commands'][0]

        print("data: %s" % data)

        self.assertEqual(result['command'], self.result['command'])
        self.assertEqual(result['returncode'], self.result['returncode'])
        self.assertEqual(result['stdout'], self.result['stdout'])
        self.assertEqual(result['stderr'], self.result['stderr'])
