import os
import unittest

from utah.client.common import (
        debug_print,
        )
from utah.client.result import ResultYAML
from utah.client import testsuite

from .common import (  # NOQA
        setUp,  # Used by nosetests
        tearDown,  # Used by nosetests
        )


def state_saver():
    debug_print("Saving state", force=True)


class TestTestSuite(unittest.TestCase):
    """
    Tests for the TestSuite class.
    """
    def setUp(self):
        """
        Use the 'examples' test suite that's part of the UTAH package.
        """
        self.name = 'examples'
        self.path = '/var/lib/utah/testsuites'
        self.assertTrue(os.path.exists(os.path.join(self.path, self.name)))
        self.suite = testsuite.TestSuite(name=self.name,
                                         path=self.path,
                                         result=ResultYAML(),
                                         _save_state_callback=state_saver)

    def test_run(self):
        print "found %d tests" % self.suite.count_tests()
        self.suite.run()
        self.assertEqual(self.suite.result.status, 'PASS')

    def test_count_tests(self):
        self.assertEquals(self.suite.count_tests(), 2)

    def test_next_test(self):
        next_test = self.suite.get_next_test()

        self.assertTrue(hasattr(next_test, 'name'))
        self.assertEquals(self.suite.get_next_test().name, 'test_one')

    def test_is_done(self):
        self.assertFalse(self.suite.is_done())

    def test_save_state(self):
        state = self.suite.save_state()

        print state
        self.assertEqual(state['status'], 'NOTRUN')

        tests = 0
        for test in state['tests']:
            self.assertEqual(test['status'], 'NOTRUN')
            tests += 1

        self.assertEqual(tests, self.suite.count_tests())

    def test_timeout_override(self):
        timeout = 101
        suite = testsuite.TestSuite(
                name=self.name,
                path=self.path,
                timeout=timeout,
                result=ResultYAML(),
                _save_state_callback=state_saver)

        self.assertEqual(timeout, suite.timeout)

        for test in suite.tests:
            self.assertEqual(timeout, test.timeout)
