"""
Provide stringification for commands used by timeout and retry.
"""


def commandstr(command, *args, **kw):
    """
    Convert a command and argument lists into a representation of that command
    suitable for display to a user.
    i.e. commandstr(command, arg1, arg2, kw1=1, kw2=2)
    should return 'command(arg1, arg2, kw1=1, kw2=2)'
    """
    msg = command.__name__ + '('
    for arg in args:
        try:
            msg += arg.__name__
        except (AttributeError, SyntaxError):
            msg += str(arg)
        msg += ', '
    for arg in kw:
        try:
            msg += arg.__name__
        except (AttributeError, SyntaxError):
            msg += str(arg)
        msg += '='
        try:
            msg += kw[arg].__name__
        except (AttributeError, SyntaxError):
            msg += str(kw[arg])
        msg += ', '
    msg = msg.rstrip(', ')
    msg += ')'
    return msg
