"""
Unix group checking functionality
"""
import grp
import os
import sys
import getpass

from utah import config


def check_user_group(group=config.group, rootok=False):
    """
    Return if the user is a member of the given group
    """
    if rootok and os.getuid() == 0:
        return True

    user_gids = os.getgroups()
    gid = grp.getgrnam(group).gr_gid

    return gid in user_gids


def print_group_error_message(script):
    """
    Print error message to stderr to be used by scripts
    """
    argv = list(sys.argv)
    argv[0] = os.path.abspath(script)
    message = ["Error: you are not in the utah group.",
               ("If you believe you have properly configured "
                "your user account for UTAH use, try:"),
               '    sudo usermod -a -G utah ' + getpass.getuser(),
               "Otherwise, please run this script as the utah user, i.e.:",
               "    sudo su - utah -c '" + ' '.join(argv) + "'\n"]
    message = '\n'.join(message)
    sys.stderr.write(message)
