"""
Process checking utilities
"""
import psutil


class ProcessChecker(object):
    """
    Check all running process looking for a given pattern
    """
    MESSAGE_TEMPLATE = \
            ("{app} application is running.\n"
            "Please stop it before launching utah since "
            "it won't interact properly with KVM "
            "(Kernel-based Virtual Machine)\n")

    def check_cmdline(self, pattern):
        """
        Check if the command line of any process matches the given pattern
        """
        pids = psutil.get_pid_list()
        cmdlines = []
        for pid in pids:
            try:
                cmdlines.append(' '.join(psutil.Process(pid).cmdline))
            except psutil.error.NoSuchProcess:
                pass
        return any(pattern in cmdline for cmdline in cmdlines)

    def get_error_message(self, app):
        """
        Return error message for an incompatible application process running
        """
        return self.MESSAGE_TEMPLATE.format(app=app)
