"""
Provide a retry loop that exits on success or an unretryable exception.
"""
import sys

from utah.exceptions import UTAHException
from utah.commandstr import commandstr


def retry(command, *args, **kw):
    """
    Retry an operation until it completes or an exception is raised without
    retry set to True.
    """
    try:
        logmethod = kw.pop('logmethod')
    except KeyError:
        logmethod = sys.stderr.write
    retval = False
    while True:
        try:
            retval = command(*args, **kw)
            return retval
        except UTAHException as err:
            try:
                if err.retry:
                    if logmethod is not None:
                        logmethod('Caught ' + str(err) + ', retrying '
                                  + commandstr(command, *args, **kw))
                else:
                    raise AttributeError
            except AttributeError:
                raise err
