"""
Consolidate the routines used to run tests into one file.
"""
import logging
import os
import time
import urllib

from utah import config
from utah.exceptions import UTAHException


def run_tests(args, machine):
    """
    Run some tests and retrieve results.
    """
    # Since we're running from a script, output INFO
    for logger in [machine.logger] + machine.logger.handlers:
        if logger.level > logging.INFO:
            logger.setLevel(logging.INFO)

    if args.json:
        extraopts = ' -f json'
        suffix = '.json'
    else:
        extraopts = ''
        suffix = '.yaml'

    locallogs = []
    exitstatus = 0

    machine.installclient()

    extraopts += " --install-type " + machine.installtype

    for runlist in args.runlists:
        locallist = urllib.urlretrieve(runlist)[0]
        machine.uploadfiles([locallist], os.path.normpath('/tmp'))

        options = ' -r /tmp/' + os.path.basename(locallist)
        utah_command = 'utah' + extraopts + options
        try:
            returncode, stdout, stderr = machine.run(utah_command)
            if returncode != 0:
                machine.logger.error('utah failed with return code: {}\n'
                                     .format(returncode))
                exitstatus = 1
                break
        except UTAHException as error:
            machine.logger.error('Failed to run test: ' + str(error))
            exitstatus = 1
            break

        listname = os.path.basename(runlist)
        locallog = os.path.join(config.logpath,
                machine.name + '_' + listname
                + time.strftime('_%Y-%m-%d_%H-%m-%S', time.gmtime())
                + suffix)
        locallog = os.path.normpath(locallog)
        with open(locallog, 'w') as f:
            f.write(stdout)
        machine.logger.info('Test log copied to ' + locallog)
        locallogs.append(locallog)

    return exitstatus, locallogs
