"""
URL tools
"""
import os
import urllib
import urllib2
import tempfile
import logging
from urlparse import urlparse
from argparse import ArgumentTypeError

import bzrlib.builtins
import bzrlib.plugin
import bzrlib.errors

from utah.exceptions import URLNotFound, URLNotReadable


# Inspired by: http://stackoverflow.com/a/2070916/183066
class HeadRequest(urllib2.Request):
    """
    Request that sends HEAD method instead of GET
    """
    def get_method(self):
        return 'HEAD'


class URLChecker(urllib.URLopener):
    """
    Check that URL exists withou opening it
    or downloading its contents
    """
    def open_http(self, url, data=None):
        """
        Check if http URL exists
        """
        # This is redundant becuase urllib2 will call urllib
        # under the hood, but makes code easy to read.
        # Note that in the case of a redirect,
        # a GET request will be sent instead of a HEAD one
        # since that's how the urllib2.HTTPRedirectHandler
        # implementation works
        url = 'http:' + url
        try:
            response = urllib2.urlopen(HeadRequest(url))
        except urllib2.URLError:
            raise URLNotFound(url)

        if response.getcode() != 200:
            raise URLNotFound(url)

        return url

    def open_local_file(self, url):
        """
        Check if local file exists
        """
        # Based on urllib.URLopener.open_local_file implementation
        host, filename = urllib.splithost(url)
        path = os.path.abspath(urllib.url2pathname(filename))

        if not os.path.exists(path):
            raise URLNotFound(path)

        if not os.access(path, os.R_OK):
            raise URLNotReadable(path)

        return path


def url_argument(url):
    """
    Check URL argument in argparse.ArgumentParser
    """
    parse_result = urlparse(url)
    if parse_result.scheme in ('', 'file', 'http', 'https'):
        url_checker = URLChecker()
        try:
            full_url = url_checker.open(url)
        except URLNotFound:
            raise ArgumentTypeError('URL not found: {}'.format(url))
        except URLNotReadable:
            raise ArgumentTypeError('URL not readable: {}'.format(url))
    elif parse_result.scheme in ('lp', 'bzr+ssh'):
        # Ignore bazaar logging messages
        bzr_logger = logging.getLogger('bzr')
        bzr_logger.addHandler(logging.NullHandler())
        bzrlib.plugin.load_plugins()  # Enable launchpad URLs in bazaar
        cmd = bzrlib.builtins.cmd_export()
        tmp_dir = tempfile.mkdtemp(prefix='utah_')
        try:
            cmd.run(tmp_dir, url)
        except bzrlib.errors.BzrError as exception:
            raise ArgumentTypeError('Bazaar export error: {}'
                                    .format(exception))
        full_url = os.path.join(tmp_dir, os.path.basename(url))
        if not os.path.isfile(full_url):
            raise ArgumentTypeError("URL doesn't point to a file "
                                    'in a bazaar branch: {}'
                                    .format(url))

    else:
        raise ArgumentTypeError('Unknown url scheme ({!r}) for url: {}'
                                .format(parse_result.scheme, url))

    return full_url
